@@ -143,7 +143,7 @@ sub languages {
                           $languages{$_}++ unless m/^-/;
                       }
                   } );
-  return keys %languages;
+    return keys %languages;
 }
 
 =head2 C<for_tu>
@@ -337,7 +337,8 @@ sub for_tu {
              seg  => sub {
                  return ($v{iscdata}) ? [ -cdata => $c ] : [ $c ]
              },
-             -cdata => sub { father->{'iscdata'} = 1; $c },
+             -cdata => sub { 
+                father->{'iscdata'} = 1; $c },
              hi   => sub { $self->{ignore_markup}?$c:toxml },
              ph   => sub { $self->{ignore_markup}?$c:toxml },
             );
@@ -349,7 +350,7 @@ sub for_tu {
 
     my $resto = "";
     ## Go through the header...
-    open X, $self->{filename} or die "cannot open file $self->{filename}\n";
+    open X, "<encoding($self->{encoding})" ,$self->{filename} or die "cannot open file $self->{filename}\n";
     while (<X>) {
         if (/^\xFF\xFE/) {
             die("UTF16 encoding not supported; try 'iconv -f unicode -t utf8 tmx' before\n");
@@ -388,10 +389,17 @@ sub for_tu {
         last if defined $conf->{proc_tu} && $i > $conf->{proc_tu} ;
         last if defined $conf->{gen_tu}  && $gen > $conf->{gen_tu};
         next if defined $conf->{patt}    && !m/$conf->{patt}/     ;
-        s/\>\s+/>/;
+        ####
+        # This can't be done. Not sure why it was being done.
+        # So, please, unless you know the implications for tagged crpora
+        # do not uncomment it.
+        #       s/\>\s+/>/;
         undef($data);
         if ($conf->{'-raw'}) {
-            $code->($_);
+            my $ans = $code->($_);
+            if ($conf->{-output}) {
+                $tmx->add_tu(-raw => $ans);
+            }
         } else {
             eval { dtstring($_, %h) } ; ## dont die in invalid XML
             warn $@ if $@;
