@@ -24,9 +24,8 @@ XML::TMX::Writer - Perl extension for writing TMX files
 
    $tmx->start_tmx(id => 'paulojjs');
 
-   $tmx->add_tu(SRCLANG => 'en', 'en' => 'some text', 'pt' => 'algum texto');
-   $tmx->add_tu(SRCLANG => 'en', 
-                'en' => 'some text', 
+   $tmx->add_tu('en' => 'some text', 'pt' => 'algum texto');
+   $tmx->add_tu('en' => 'some text', 
                 'pt' => 'algum texto',
                  -note => [32, 34 ],
                  -prop => { q => 23,
@@ -262,8 +261,9 @@ sub start_tmx {
           or die "Cannot open file '$options{'-output'}': $!\n";
     }
 
-    binmode $self->{OUTPUT}, ":utf8" if $encoding =~ m!utf.?8!i;
-
+    if ($encoding =~ m!utf.?8!i) {
+        binmode $self->{OUTPUT}, ":utf8" 
+    }
     $self->_write("<?xml version=\"1.0\" encoding=\"$encoding\"?>\n");
 
     my @valid_segtype = qw'block sentence paragraph phrase';
@@ -384,6 +384,13 @@ sub add_tu {
     my $verbatim = 0;
     my $cdata = 0;
 
+    if (exists($tuv{-raw})) {
+        # value already includes <tu> tags, hopefully, at least!
+        # so we will not mess with it.
+        $self->_write($tuv{-raw});
+        return;
+    }
+
     for my $key (qw'id datatype segtype srclang creationid creationdate') {
         if (exists($tuv{$key})) {
             $opt{$key} = $tuv{$key};
